/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.impl.speech;

import java.util.logging.Logger;
import javax.jms.Destination;
import javax.jms.Session;
import org.robokind.api.common.utils.Adapter;
import org.robokind.api.common.utils.TimeUtils;
import org.robokind.api.speech.SpeechRequest;
import org.robokind.avrogen.speech.SpeechRequestRecord;
import org.robokind.impl.messaging.JMSAvroMessageSender;

/**
 * JMSAvroMessageSender for sending SpeechRequests.
 * @author Matthew Stevenson <www.robokind.org>
 */
public class JMSSpeechRequestSender extends 
        JMSAvroMessageSender<SpeechRequest, SpeechRequestRecord> {
    static final Logger theLogger = Logger.getLogger(JMSSpeechRequestSender.class.getName());
    private String mySourceId;
    private String myDestinationId;
    
    public JMSSpeechRequestSender(Session session, Destination destination){
        super(session, destination);
        setAdapter(new SpeechRequestAdapter());
    }
    
    public void setSourceId(String sourceId){
        mySourceId = sourceId;
    }
    
    public void setDestinationId(String destId){
        myDestinationId = destId;
    }
    
    /**
     * Creates and sends a SpeechRequest from the given text.
     * @param text the text to speak
     */
    public void sendSpeechRequest(String text){
        if(text == null || mySourceId == null || myDestinationId == null){
            throw new NullPointerException();
        }
        SpeechRequest request = 
                new PortableSpeechRequest(
                        mySourceId, myDestinationId, TimeUtils.now(), text);
        super.sendMessage(request);
    }
    
    /**
     * Converts a SpeechRequest to a SpeechRequestRecord to be sent.
     */
    public static class SpeechRequestAdapter 
            implements Adapter<SpeechRequest, SpeechRequestRecord>{
        @Override
        public SpeechRequestRecord adapt(SpeechRequest a) {
            if(a instanceof PortableSpeechRequest){
                return ((PortableSpeechRequest)a).getRecord();
            }
            return new PortableSpeechRequest(a).getRecord();
        }
    }
    
}
