/*
 * Copyright 2011 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.impl.speech;

import java.util.ArrayList;
import java.util.List;
import org.robokind.api.common.utils.Adapter;
import org.robokind.api.speech.SpeechEvent;
import org.robokind.api.speech.SpeechEventList;
import org.robokind.avrogen.speech.SpeechEventListRecord;
import org.robokind.avrogen.speech.SpeechEventRecord;

/**
 * SpeechEventList implementation wrapping a SpeechEventListRecord.
 * Converts the SpeechEventsRecords to a List of PortableSpeechEvents.
 * 
 * @author Matthew Stevenson <www.robokind.org>
 */
public class PortableSpeechEventList implements SpeechEventList{
    private SpeechEventListRecord myListRecord;
    private List<SpeechEvent> myEvents;
    
    /**
     * Creates a new PortableSpeechEventList from the given Record
     * @param record SpeechEventListRecord to wrap
     */
    public PortableSpeechEventList(SpeechEventListRecord record){
        if(record == null){
            throw new NullPointerException();
        }
        myListRecord = record;
        myEvents = new ArrayList<SpeechEvent>(myListRecord.speechEvents.size());
        Adapter<SpeechEventRecord,SpeechEvent> adapter = 
                new PortableSpeechEvent.RemoteSpeechEventAdapter();
        for(SpeechEventRecord rec : myListRecord.speechEvents){
            myEvents.add(adapter.adapt(rec));
        }
    }
    
    @Override
    public String getSpeechServiceId() {
        return myListRecord.speechServiceId.toString();
    }

    @Override
    public long getTimestampMillisecUTC() {
        return myListRecord.timestampMillisecUTC;
    }

    @Override
    public List<SpeechEvent> getSpeechEvents() {
        return myEvents;
    }
    
    /**
     * Converts a SpeechEventListRecord to a PortableSpeechEventList
     */
    public static class RemoteSpeechEventListAdapter 
            implements Adapter<SpeechEventListRecord,SpeechEventList>{
        @Override
        public SpeechEventList adapt(SpeechEventListRecord a) {
            return new PortableSpeechEventList(a);
        }
        
    }
}
